# Using C++ to access an output database

The following sections describe the architecture of an output database and how to use the Abaqus C++ Application Programming Interface (API) to access data from an output database.

```{toctree}
:caption: Contents
:maxdepth: 1

about
need-what-access
style
object-model
output-object-model
compile-link
access
architecture
utility
read
write
exceptions
computations
improve-efficiency
examples
```
